@@ -107,7 +107,7 @@ from processor.helper.json.json_utils import get_field_value, json_from_file,\
     make_snapshots_dir, store_snapshot
 from processor.helper.yaml.yaml_utils import yaml_from_file
 from processor.helper.config.config_utils import config_value, get_test_json_dir, EXCLUSION
-from processor.helper.config.rundata_utils import get_from_currentdata, get_dbtests
+from processor.helper.config.rundata_utils import get_from_currentdata, get_dbtests, put_in_currentdata
 from processor.database.database import insert_one_document, sort_field, get_documents,\
     COLLECTION, DATABASE, DBNAME, get_collection_size, create_indexes
 from processor.helper.httpapi.restapi_azure import json_source
@@ -358,14 +358,26 @@ def populate_custom_snapshot(snapshot, container=None):
                             node['status'] = 'inactive'
                         logger.debug('Type: %s', type(data))
                     elif 'masterSnapshotId' in node:
+                        includeSnapshotConfig = get_from_currentdata("INCLUDESNAPSHOTS")
+                        includeSnapshots = get_from_currentdata("SNAPHSHOTIDS")
+                        ignoreExclusion = False
+                        ignoreNode = False
+                        if includeSnapshotConfig:
+                            if node['masterSnapshotId'] in includeSnapshots:
+                                ignoreExclusion = True
+                                ignoreNode = False
+                            else:
+                                ignoreNode  = True
                         alldata = get_all_nodes(repopath, node, snapshot, brnch, sub_data)
                         if alldata:
                             exclusions = get_from_currentdata(EXCLUSION).get('exclusions', [])
+
                             resourceExclusions = {}
-                            for exclusion in exclusions:
-                                if 'exclusionType' in exclusion and exclusion['exclusionType'] and exclusion['exclusionType'] == 'resource':
-                                    if 'paths' in exclusion and isinstance(exclusion['paths'], list):
-                                        resourceExclusions[tuple(exclusion['paths'])] = exclusion
+                            if not ignoreExclusion:
+                                for exclusion in exclusions:
+                                    if 'exclusionType' in exclusion and exclusion['exclusionType'] and exclusion['exclusionType'] == 'resource':
+                                        if 'paths' in exclusion and isinstance(exclusion['paths'], list):
+                                            resourceExclusions[tuple(exclusion['paths'])] = exclusion
 
                             snapshot_data[node['masterSnapshotId']] = []
                             for data in alldata:
@@ -378,16 +390,18 @@ def populate_custom_snapshot(snapshot, container=None):
                                 if key and key in resourceExclusions:
                                     logger.warning("Excluded from resource exclusions: %s", data['path'])
                                     continue
-                                snapshot_data[node['masterSnapshotId']].append(
-                                    {
-                                        'snapshotId': data['snapshotId'],
-                                        'path': data['path'],
-                                        'validate': validate
-                                    })
+                                if not ignoreNode:
+                                    snapshot_data[node['masterSnapshotId']].append(
+                                        {
+                                            'snapshotId': data['snapshotId'],
+                                            'path': data['path'],
+                                            'validate': validate
+                                        })
                         logger.debug('Type: %s', type(alldata))
         if baserepo and os.path.exists(baserepo):
             # logger.info('\t\tCLEANING Repo: %s', baserepo)
-            shutil.rmtree(baserepo)
+            put_in_currentdata("CLEANING_REPOS", baserepo)
+            # shutil.rmtree(baserepo)
     return snapshot_data
 
 
